/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.annotators.quantities;

import de.unibi.techfak.scie.annotators.AnnotationCounter;
import de.unibi.techfak.isy.lppba.descriptors.InexactQuantity;
import java.util.Collection;

import org.apache.uima.analysis_engine.AnalysisEngineProcessException;
import org.apache.uima.fit.util.JCasUtil;
import org.apache.uima.jcas.JCas;

import de.unibi.techfak.isy.lppba.descriptors.LanguageQuantifier;

/**
 * This annotates InexactQuantities, which means LanguageQuantifiers in the text. This basically
 * copies LanguageQuantifier-Annotations to have Quantity-instances for them as UIMA does not allow
 * multiple inheritance.
 *
 * This is based on the OntologyAnnotator.
 *
 * @author Benjamin Paassen - bpaassen@techfak.uni-bielefeld.de
 */
public class InexactQuantityAnnotator extends org.apache.uima.fit.component.JCasAnnotator_ImplBase {

	public InexactQuantityAnnotator() {
	}
	@Override
	public void process(JCas jcas) throws AnalysisEngineProcessException {
		final Collection<LanguageQuantifier> languageQuantifiers =
				JCasUtil.select(jcas, LanguageQuantifier.class);
		for (final LanguageQuantifier q : languageQuantifiers) {
			final InexactQuantity qWrapper = new InexactQuantity(jcas, q.getBegin(), q.getEnd());
			qWrapper.setQuantifier(q);
			qWrapper.setAnnotationId(AnnotationCounter.getUniqueId());
			qWrapper.addToIndexes();
		}
	}
}
