/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.annotators.quantities;

import de.unibi.techfak.scie.annotators.AnnotationCounter;
import java.util.List;

import org.apache.uima.jcas.JCas;

import de.unibi.techfak.isy.lppba.descriptors.Quantity;
import de.unibi.techfak.isy.lppba.descriptors.Time;
import de.unibi.techfak.isy.lppba.descriptors.Token;

/**
 * This annotates times.
 * 
 * @author Benjamin Paassen - bpaassen(at)techfak.uni-bielefeld.de
 */
public class TimeAnnotator extends UnitQuantityAnnotator {

	private static final Unit[] units = { Unit.MILLISECONDS, Unit.SECONDS,
			Unit.MINUTES, Unit.HOURS, Unit.DAYS, Unit.WEEKS, Unit.MONTHS, Unit.YEARS };

	public static double convertToSIValue(final Unit currentUnit,
			final double currentValue) {
		switch (currentUnit) {
		case MILLISECONDS:
			return currentValue / 1000;
		case SECONDS:
			return currentValue;
		case MINUTES:
			return currentValue * 60;
		case HOURS:
			return convertToSIValue(Unit.MINUTES, currentValue * 60);
		case DAYS:
			return convertToSIValue(Unit.HOURS, currentValue * 24);
		case WEEKS:
			return convertToSIValue(Unit.DAYS, currentValue * 7);
		case MONTHS:
			return convertToSIValue(Unit.DAYS, currentValue * 30);
		case YEARS:
			return convertToSIValue(Unit.DAYS, currentValue * 365);
		default:
			throw new RuntimeException("Unrecognized Time Unit: " + currentUnit);
		}
	}

	public TimeAnnotator() {
		super(units);
	}

	@Override
	public void handleQuantity(Quantity q, Unit unit, List<Token> unitTokens,
			JCas jcas) {
		Token unitToken = unitTokens.get(0);
		// calculate the standard value if possible
		final double SIValue;
		if (q instanceof de.unibi.techfak.isy.lppba.descriptors.Integer) {
			SIValue = convertToSIValue(unit,
					((de.unibi.techfak.isy.lppba.descriptors.Integer) q).getValue());
		} else if (q instanceof de.unibi.techfak.isy.lppba.descriptors.Double) {
			SIValue = convertToSIValue(unit,
					((de.unibi.techfak.isy.lppba.descriptors.Double) q).getValue());
		} else {
			SIValue = -1;
		}
		// then create the annotation.
		final int begin = q.getBegin();
		final int end = unitToken.getEnd();
		final Time time = new Time(jcas, begin, end);
		time.setUnitName(unit.getNormalizedName());
		time.setValue(q);
		time.setSIValue(SIValue);
		time.setAnnotationId(AnnotationCounter.getUniqueId());
		time.addToIndexes();
	};
}
