/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.annotators.structure;

import de.unibi.techfak.isy.lppba.descriptors.DocumentPage;
import de.unibi.techfak.isy.lppba.descriptors.Emphasized;
import de.unibi.techfak.isy.lppba.descriptors.Strong;
import de.unibi.techfak.isy.lppba.descriptors.Subscript;
import de.unibi.techfak.isy.lppba.descriptors.Superscript;
import de.unibi.techfak.scie.pdfextractor.structure.Document;
import de.unibi.techfak.scie.pdfextractor.structure.Page;
import de.unibi.techfak.scie.pdfextractor.structure.Paragraph;
import de.unibi.techfak.scie.pdfextractor.structure.Text;
import de.unibi.techfak.scie.pdfextractor.structure.TextBlock;
import org.apache.uima.analysis_engine.AnalysisEngineProcessException;
import org.apache.uima.jcas.JCas;

/**
 * This annotates the page structure in Documents that have been imported by the
 * PDFStructuredTextExctractor.
 * 
 * @author Benjamin Paassen - bpaassen@techfak.uni-bielefeld.de
 */
public class StructureAnnotator extends
		org.apache.uima.fit.component.JCasAnnotator_ImplBase {

	private final Document doc;

	public StructureAnnotator(Document doc) {
		this.doc = doc;
	}

	@Override
	public void process(JCas jcas) throws AnalysisEngineProcessException {
		/*
		 * We basically just copy the structure information retrieved by the
		 * PDFStructuredTextExctractor.
		 */
		for (final Page page : doc.content) {
			// copy Pages
			final DocumentPage uimaPage = new DocumentPage(jcas, page.getBegin(),
					page.getEnd());
			uimaPage.setPageNumber(page.getPageNumber());
			uimaPage.addToIndexes();
			for (final TextBlock block : page.content) {
				// copy TextBlocks
				final de.unibi.techfak.isy.lppba.descriptors.TextBlock uimaBlock = new de.unibi.techfak.isy.lppba.descriptors.TextBlock(
						jcas, block.getBegin(), block.getEnd());
				uimaBlock.setRelativeFontSize(block.getRelativeFontSize());
				uimaBlock.addToIndexes();
				for (final Paragraph par : block.content) {
					// copy Paragraphs
					final de.unibi.techfak.isy.lppba.descriptors.Paragraph uimaPar = new de.unibi.techfak.isy.lppba.descriptors.Paragraph(
							jcas, par.getBegin(), par.getEnd());
					uimaPar.addToIndexes();
					for (final Text text : par.content) {
						// copy italic, bold and sub- or superscript.
						if (text.getFontName() != null) {
							final String fontName = text.getFontName().toLowerCase();
							if (fontName.contains("bold")) {
								final Strong strong = new Strong(jcas, text.getBegin(),
										text.getEnd());
								strong.addToIndexes();
							}
							if (fontName.contains("italic")) {
								final Emphasized em = new Emphasized(jcas, text.getBegin(),
										text.getEnd());
								em.addToIndexes();
							}
						}
						switch (text.getVerticalAlignment()) {
						case SUBSCRIPT:
							final Subscript subscript = new Subscript(jcas, text.getBegin(),
									text.getEnd());
							subscript.addToIndexes();
							break;
						case SUPERSCRIPT:
							final Superscript superscript = new Superscript(jcas,
									text.getBegin(), text.getEnd());
							superscript.addToIndexes();
							break;
						}
					}
				}
			}
		}
	}
}