/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.db;

import de.unibi.techfak.scie.configuration.ConfigurationEntry;
import de.unibi.techfak.scie.configuration.ConfigurationSet;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Properties;

/**
 *
 * @author Andreas Stoeckel -- astoecke(at)techfak.uni-bielefeld.de
 */
public abstract class JDBCRemoteDatabaseInstance extends JDBCDatabaseInstance {

	public JDBCRemoteDatabaseInstance(ConfigurationSet configuration) {
		super(configuration);
	}

	protected abstract String getURLPrefix();

	@Override
	protected String getURL() {
		final String prefix = getURLPrefix();
		final String host = config.getValue("host");
		final String port = config.getValue("port");
		final String db = config.getValue("database");
		return "jdbc:" + prefix + "://" + host + ":" + port + "/" + db;
	}

	@Override
	protected Properties getProperties() {
		Properties props = new Properties();
		props.setProperty("user", config.getValue("user"));
		props.setProperty("password", config.getValue("password"));
		return props;
	}

	protected static Collection<ConfigurationEntry> getConfigurationEntries(final int defaultPort) {
		Collection<ConfigurationEntry> entries = new ArrayList();
		entries.add(new ConfigurationEntry(
				"host",
				"The database host",
				"localhost"));
		entries.add(new ConfigurationEntry(
				"port",
				"The port the database should connect to",
				Integer.toString(defaultPort)));
		entries.add(new ConfigurationEntry(
				"database",
				"The name of the database that should be used",
				"lppba"));
		entries.add(new ConfigurationEntry(
				"user",
				"The user that should be used to connect to the database",
				"root"));
		entries.add(new ConfigurationEntry(
				"password",
				"The password that should be used to connect to the database",
				"root"));
		return entries;
	}

}
