/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.probability_model;

/**
 * This is a common interface for classes that implement the functionality to
 * model the semantic probability
 *
 * P(w' semanticly belongs to w|w' syntactically belongs to w)
 *
 * @param <X> The AnnotationCandidate type.
 *
 * @author Benjamin Paassen - bpaassen(at)techfak.uni-bielefeld.de
 */
public interface SemanticProbabilityModel<X extends AnnotationCandidate> {

	/**
	 * This should calculate the semantic probabilty of an AnnotationCandidate 
	 * belonging to another 
	 *
	 * If additional information is required to derive this value set those
	 * parameters in some other way (e.g. the given AnnotationCandidate
	 * implementation).
	 *
	 * @param candidate an AnnotationCandidate of Type X.
	 * @return likelihood probabilty of an AnnotationCandidate 
	 * belonging to a larger composit annotation
	 */
	public double calculateSemanticProbability(final X candidate);
}
