/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.annotators.injury;

import de.unibi.techfak.scie.annotators.injury.VertebralPositionAnnotator;
import de.unibi.techfak.scie.annotators.injury.VertebralPositionRangeAnnotator;
import de.unibi.techfak.scie.annotators.quantities.NumberAnnotator;
import de.unibi.techfak.scie.annotators.quantities.RangeAnnotator;
import de.unibi.techfak.scie.annotators.structure.StanfordTokenizer;
import de.unibi.techfak.isy.lppba.descriptors.VertebralPosition;
import de.unibi.techfak.isy.lppba.descriptors.VertebralPositionRanged;

import java.util.Collection;
import java.util.Iterator;

import static junit.framework.Assert.assertEquals;
import junit.framework.TestCase;

import org.apache.uima.fit.factory.JCasFactory;
import org.apache.uima.fit.util.JCasUtil;
import org.apache.uima.jcas.JCas;

/**
 *
 * @author socnow
 */
public class VertebralPositionRangeAnnotatorTest extends TestCase {

	public VertebralPositionRangeAnnotatorTest(String testName) {
		super(testName);
	}

	@Override
	protected void setUp() throws Exception {
		super.setUp();
	}

	@Override
	protected void tearDown() throws Exception {
		super.tearDown();
	}

	/**
	 * Test of process method, of class VertebralPositionAnnotator.
	 */
	public void testProcess() throws Exception {
		//create example
		final JCas jcas = JCasFactory.createJCas(
				"src/main/resources/de/unibi/techfak/isy/lppba/descriptors/LPPBATypeSystem");
		jcas.setDocumentText(
				"four-level T5-T8 laminectomy. between T1 and T3. from T2 to T4. ");
		//preprosess using StanfordTokenizer, NumberAnnotator and RangeAnnotator
		final StanfordTokenizer st = new StanfordTokenizer();
		st.process(jcas);
		final NumberAnnotator na = new NumberAnnotator();
		na.process(jcas);
		final RangeAnnotator ra = new RangeAnnotator();
		ra.process(jcas);
		final VertebralPositionAnnotator vpa =
				new VertebralPositionAnnotator();
		vpa.process(jcas);

		//use the VertebralPositionRangeAnnotator
		final VertebralPositionRangeAnnotator instance=
				new VertebralPositionRangeAnnotator();
		instance.process(jcas);
		
		//check results
		final Collection<VertebralPositionRanged> vps = JCasUtil.select(jcas,
				VertebralPositionRanged.class);

		final Iterator<VertebralPositionRanged> iterator = vps.iterator();

		assertTrue(iterator.hasNext());
		VertebralPositionRanged vp = iterator.next();
		assertEquals("T5-T8", vp.getCoveredText());
		assertEquals("Thoracic",vp.getRegion());
		
		VertebralPosition low=vp.getLowVal();
		assertEquals("T5",low.getCoveredText());
		assertEquals("Thoracic",low.getRegion());

		VertebralPosition high=vp.getHighVal();
		assertEquals("T8",high.getCoveredText());
		
		assertTrue(iterator.hasNext());
		vp = iterator.next();
		low=vp.getLowVal();
		high=vp.getHighVal();
		assertEquals("T1",low.getCoveredText());
		assertEquals("T3",high.getCoveredText());
		
		assertTrue(iterator.hasNext());
		vp = iterator.next();
		low=vp.getLowVal();
		high=vp.getHighVal();
		assertEquals("T2",low.getCoveredText());
		assertEquals("T4",high.getCoveredText());
		
		assertFalse(iterator.hasNext());
		}
}
