/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.annotators.ontology;

import de.unibi.techfak.scie.annotators.ontology.OntologyAnnotator;
import de.unibi.techfak.scie.db.DatabaseSingleton;
import de.unibi.techfak.isy.lppba.descriptors.Organism;

import java.util.Iterator;

import static junit.framework.Assert.assertEquals;
import static junit.framework.Assert.assertTrue;
import junit.framework.TestCase;

import org.apache.uima.fit.factory.JCasFactory;
import org.apache.uima.fit.util.JCasUtil;
import org.apache.uima.jcas.JCas;

/**
 *
 * @author Benjamin Paassen - bpaassen(at)techfak.uni-bielefeld.de
 */
public class OntologyAnnotatorTest extends TestCase {

	public OntologyAnnotatorTest(String testName) {
		super(testName);
	}

	@Override
	protected void setUp() throws Exception {
		super.setUp();
	}

	@Override
	protected void tearDown() throws Exception {
		super.tearDown();
	}

	/**
	 * Test of process method, of class OntologyAnnotator.
	 */
	public void testProcess() throws Exception {
		DatabaseSingleton.initialize("./config.xml");

		//create example
		final JCas jcas = JCasFactory.createJCas(
				"src/main/resources/de/unibi/techfak/isy/lppba/descriptors/LPPBATypeSystem");
		jcas.setDocumentText("increase increasing rat.");

		//use OntologyAnnotator.
		final OntologyAnnotator instance = new OntologyAnnotator();
		instance.process(jcas);


		//check results
		final Iterator<Organism> actual = JCasUtil.select(jcas, Organism.class).iterator();
		//the animals we found should only be database node 10118 and 10116
		assertTrue(actual.hasNext());

		Organism orga = actual.next();
		assertEquals("rat", orga.getCoveredText());
		assertEquals(10118, orga.getId());
		//probability 0.75, because 10118 has the node name "rats"
		assertEquals(0.75, orga.getProbability(), 0);

		assertTrue(actual.hasNext());

		orga = actual.next();
		assertEquals("rat", orga.getCoveredText());
		assertEquals(10116, orga.getId());
		assertEquals(1.0, orga.getProbability(), 0);

		assertFalse(actual.hasNext());
	}
}
