/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.annotators.quantities;

import de.unibi.techfak.scie.annotators.quantities.NumberAnnotator;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.util.Collection;
import java.util.HashSet;
import java.util.Iterator;
import static junit.framework.Assert.assertEquals;
import junit.framework.TestCase;
import org.apache.uima.fit.factory.JCasFactory;
import org.apache.uima.fit.util.JCasUtil;
import org.apache.uima.jcas.JCas;

/**
 *
 * @author Benjamin Paassen - bpaassen(at)techfak.uni-bielefeld.de
 */
public class NumberAnnotatorTest extends TestCase {

	public NumberAnnotatorTest(String testName) {
		super(testName);
	}

	@Override
	protected void setUp() throws Exception {
		super.setUp();
	}

	@Override
	protected void tearDown() throws Exception {
		super.tearDown();
	}

	/**
	 * Test of process method, of class NumberAnnotator.
	 */
	public void testProcess() throws Exception {
		final NumberAnnotator instance = new NumberAnnotator();
		final JCas jcas = JCasFactory.createJCas(
				"src/main/resources/de/unibi/techfak/isy/lppba/descriptors/LPPBATypeSystem");
		//load example data
		final File exampleFile = new File("testdata/numbers.txt");
		final BufferedReader exampleInput = new BufferedReader(new FileReader(
				exampleFile));
		boolean integerExamples = true;
		String currentLine;
		while ((currentLine = exampleInput.readLine()) != null) {
			if (currentLine.equals("Doubles")) {
				integerExamples = false;
				continue;
			}

			final String[] split = currentLine.split("\\:");
			final String testString = split[0];
			final String[] numberSplit = split[1].split("\\,");
			if (integerExamples) {
				final HashSet<Integer> expected = new HashSet<>();
				for (int i = 0; i < numberSplit.length; i++) {
					expected.add(Integer.parseInt(numberSplit[i]));
				}

				//set up jcas
				jcas.setDocumentLanguage("en");
				jcas.setDocumentText(testString);
				//then use NumberAnnotator
				instance.process(jcas);
				//check results
				final Collection<de.unibi.techfak.isy.lppba.descriptors.Integer> ints =
						JCasUtil.select(jcas,
						de.unibi.techfak.isy.lppba.descriptors.Integer.class);
				final HashSet<Integer> actual = new HashSet<>();
				final Iterator<de.unibi.techfak.isy.lppba.descriptors.Integer> iterator =
						ints.iterator();
				while (iterator.hasNext()) {
					actual.add(iterator.next().getValue());
				}
				assertEquals(expected, actual);
			} else {
				final HashSet<Double> expected = new HashSet<>();
				for (int i = 0; i < numberSplit.length; i++) {
					expected.add(Double.parseDouble(numberSplit[i]));
				}

				//set up jcas
				jcas.setDocumentLanguage("en");
				jcas.setDocumentText(testString);
				//then use NumberAnnotator
				instance.process(jcas);
				//check results
				final Collection<de.unibi.techfak.isy.lppba.descriptors.Double> doubles =
						JCasUtil.select(jcas,
						de.unibi.techfak.isy.lppba.descriptors.Double.class);
				final HashSet<Double> actual = new HashSet<>();
				final Iterator<de.unibi.techfak.isy.lppba.descriptors.Double> iterator =
						doubles.iterator();
				while (iterator.hasNext()) {
					actual.add(iterator.next().getValue());
				}
				assertEquals(expected, actual);
			}
			//reset jcas
			jcas.reset();
		}
	}
}
