/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.annotators.quantities;

import de.unibi.techfak.scie.annotators.quantities.RomanNumberAnnotator;
import java.util.regex.Matcher;
import junit.framework.TestCase;

/**
 *
 * @author Benjamin Paassen - bpaassen(at)techfak.uni-bielefeld.de
 */
public class RomanNumberAnnotatorTest extends TestCase {

	public RomanNumberAnnotatorTest(String testName) {
		super(testName);
	}

	@Override
	protected void setUp() throws Exception {
		super.setUp();
	}

	@Override
	protected void tearDown() throws Exception {
		super.tearDown();
	}

	/**
	 * Test of parseRomanInt method, of class RomanNumberAnnotator.
	 */
	public void testParseRomanInt() throws Exception {
		final RomanNumberAnnotator instance = new RomanNumberAnnotator();
		final String[] strings = {"II", "IV", "VII", "IX", "XIII", "XIV",
			"XLIII", "LXIV", "XC",
			"CCC", "CD", "DCCC", "CM", "MMMCMXCIX"};
		final int[] expected = {2, 4, 7, 9, 13, 14, 43, 64, 90, 300, 400, 800,
			900, 3999};
		assertEquals(strings.length, expected.length);
		for (int i = 0; i < expected.length; i++) {
			final Matcher matcher = RomanNumberAnnotator.ROMANINT.matcher(
				strings[i].toLowerCase());
			assertTrue(strings[i] + " is no roman literal according to pattern.",
				matcher.matches());
			assertEquals(expected[i], instance.parseRomanInt(matcher.group(1),
				matcher.group(2),
				matcher.group(3), matcher.group(4)));
		}
	}
}
