/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.annotators.quantities;

import de.unibi.techfak.scie.annotators.quantities.NumberAnnotator;
import de.unibi.techfak.scie.annotators.quantities.WordNumberAnnotator;
import de.unibi.techfak.scie.annotators.quantities.TimeAnnotator;
import de.unibi.techfak.scie.annotators.ontology.OntologyAnnotator;
import de.unibi.techfak.scie.annotators.structure.StanfordTokenizer;
import java.util.Collection;

import org.apache.uima.fit.factory.JCasFactory;
import org.apache.uima.fit.util.JCasUtil;
import org.apache.uima.jcas.JCas;

import de.unibi.techfak.scie.db.DatabaseSingleton;
import de.unibi.techfak.isy.lppba.descriptors.Time;
import java.util.HashSet;
import junit.framework.TestCase;

public class TimeAnnotatorTest extends TestCase {

	public TimeAnnotatorTest(String testName) {
		super(testName);
	}

	@Override
	protected void setUp() throws Exception {
		super.setUp();
		DatabaseSingleton.initialize("./config.xml");
	}

	@Override
	protected void tearDown() throws Exception {
		super.tearDown();
	}

	/**
	 * Test of process method, of class TimeAnnotator.
	 */
	public void testProcess() throws Exception {

		//create example
		final JCas jcas = JCasFactory.createJCas(
			"src/main/resources/de/unibi/techfak/isy/lppba/descriptors/LPPBATypeSystem");
		jcas.setDocumentText("A 10 years old man. A one day old man. A 1,3 h test.");
		//preprosess using StanfordTokenizer, NumberAnnotator and WordNumberAnnotator
		final StanfordTokenizer st = new StanfordTokenizer();
		st.process(jcas);
		final NumberAnnotator numberAnnotator = new NumberAnnotator();
		numberAnnotator.process(jcas);
		final OntologyAnnotator ontoAnnotator = new OntologyAnnotator();
		ontoAnnotator.process(jcas);
		final WordNumberAnnotator wordNumberAnnotator = new WordNumberAnnotator();
		wordNumberAnnotator.process(jcas);

		//use the TimeAnnotator
		final TimeAnnotator instance = new TimeAnnotator();
		instance.process(jcas);

		//check results
		final Collection<Time> timeInstances = JCasUtil.select(jcas, Time.class);

		final String[] expected = {"10 years", "one day", "1,3 h"};

		final HashSet<String> actual = new HashSet<>();
		for (final Time t : timeInstances) {
			actual.add(t.getCoveredText());
		}
		for (final String exp : expected) {
			assertTrue(exp + " was expected but not found!", actual.contains(exp));
		}
	}
}
