/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.annotators.quantities;

import de.unibi.techfak.scie.annotators.quantities.WordNumberAnnotator;
import de.unibi.techfak.scie.annotators.ontology.OntologyAnnotator;
import de.unibi.techfak.scie.db.DatabaseSingleton;
import java.util.Collection;
import java.util.HashSet;
import junit.framework.TestCase;
import org.apache.uima.fit.factory.JCasFactory;
import org.apache.uima.fit.util.JCasUtil;
import org.apache.uima.jcas.JCas;

/**
 *
 * @author socnow
 */
public class WordNumberAnnotatorTest extends TestCase {

	public WordNumberAnnotatorTest(String testName) {
		super(testName);
	}

	@Override
	protected void setUp() throws Exception {
		super.setUp();
		DatabaseSingleton.initialize("./config.xml");
	}

	@Override
	protected void tearDown() throws Exception {
		super.tearDown();
	}

	public void testNumberWords() throws Exception {

		//initialization
		final OntologyAnnotator ontoAnnotator = new OntologyAnnotator();
		final WordNumberAnnotator instance = new WordNumberAnnotator();
		final JCas jcas = JCasFactory.createJCas(
				"src/main/resources/de/unibi/techfak/isy/lppba/descriptors/LPPBATypeSystem");

		final int[] expected = {1, 12, 42, 21};
		//set up jcas
		jcas.setDocumentLanguage("en");
		jcas.setDocumentText(
				"There's one answer to a dozen questions: Fortytwo! But maybe also twenty-one.");
		//use OntologyAnnotator as preprocessing
		ontoAnnotator.process(jcas);
		//then use WordNumberAnnotator
		instance.process(jcas);
		//check results

		final Collection<de.unibi.techfak.isy.lppba.descriptors.Integer> ints =
				JCasUtil.select(jcas,
				de.unibi.techfak.isy.lppba.descriptors.Integer.class);

		final HashSet<Integer> found = new HashSet<>();
		for (final de.unibi.techfak.isy.lppba.descriptors.Integer i : ints) {
			found.add(i.getValue());
		}
		for (final int exp : expected) {
			assertTrue(exp + " was expected but not found!", found.contains(exp));
		}
	}
}
