/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.annotators.result;

import de.unibi.techfak.scie.annotators.result.PValueAnnotator;
import de.unibi.techfak.scie.annotators.quantities.NumberAnnotator;
import de.unibi.techfak.scie.annotators.structure.StanfordTokenizer;
import de.unibi.techfak.isy.lppba.descriptors.PValue;
import java.util.Collection;
import java.util.Iterator;
import static junit.framework.Assert.assertEquals;
import junit.framework.TestCase;
import org.apache.uima.fit.factory.JCasFactory;
import org.apache.uima.fit.util.JCasUtil;
import org.apache.uima.jcas.JCas;

/**
 *
 * @author Benjamin Paassen - bpaassen(at)techfak.uni-bielefeld.de
 */
public class PValueAnnotatorTest extends TestCase {

	public PValueAnnotatorTest(String testName) {
		super(testName);
	}

	@Override
	protected void setUp() throws Exception {
		super.setUp();
	}

	@Override
	protected void tearDown() throws Exception {
		super.tearDown();
	}

	/**
	 * Test of process method, of class PValueAnnotator.
	 */
	public void testProcess() throws Exception {

		//create example
		final JCas jcas = JCasFactory.createJCas(
				"src/main/resources/de/unibi/techfak/isy/lppba/descriptors/LPPBATypeSystem");
		jcas.setDocumentText(
				"Thus we conclude with a certainty of P<=0.01 that communist gouvernance " +
				"is most effective while with P < 'o' 0.000072 we could ensure that capitalist " +
				"politics is not expected to be a good basis for a democratic society." +
				"We did this by comparing P=99 societies of forementioned types each with " +
				"probability pT = 0.4. Benachmark was P0.05 level.");
		//preprosess using StanfordTokenizer and NumberAnnotator
		final StanfordTokenizer st = new StanfordTokenizer();
		st.process(jcas);
		final NumberAnnotator na = new NumberAnnotator();
		na.process(jcas);

		//use the PValueAnnotator
		final PValueAnnotator instance = new PValueAnnotator();
		instance.process(jcas);

		//check results
		final Collection<PValue> pvals = JCasUtil.select(jcas, PValue.class);
		final String[] expected = {"P<=0.01", "P < 'o' 0.000072", "P0.05"};
		final double[] expectedVals = {0.01, 0.000072, 0.05};
		assertEquals(expected.length, pvals.size());
		final Iterator<PValue> iterator = pvals.iterator();
		for (int i = 0; i < expected.length; i++) {
			final PValue pval = iterator.next();
			assertEquals(expected[i], pval.getCoveredText());
			assertEquals(expectedVals[i], pval.getValue().getValue());
		}

	}
}
