/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.ontology.importer.small;

import java.io.File;
import java.util.Collection;

import de.unibi.techfak.scie.db.DatabaseSingleton;
import de.unibi.techfak.scie.ontology.Node;
import de.unibi.techfak.scie.ontology.OntologyDatabase;
import de.unibi.techfak.scie.ontology.driver.AssociationType;
import de.unibi.techfak.scie.ontology.driver.ComparisonMode;
import de.unibi.techfak.scie.ontology.driver.NodeDescriptor;
import de.unibi.techfak.scie.ontology.driver.NodeHandle;
import de.unibi.techfak.scie.ontology.driver.NodeName;
import de.unibi.techfak.scie.ontology.driver.OntologyHandle;
import de.unibi.techfak.scie.ontology.importer.XMLImporter;
import junit.framework.TestCase;

public class SmallImporterTest extends TestCase {

	public SmallImporterTest(String testName) {
		super(testName);
	}

	@Override
	protected void setUp() throws Exception {
		super.setUp();
	}

	@Override
	protected void tearDown() throws Exception {
		super.tearDown();
	}

	/**
	 * Test of imported Data(see pom.xml).
	 */
	public void testImportedData() throws Exception {
		String[] args = {"small", "./config_dbtest.xml", "testdata/smallontotest.xml", "override"};
		assertTrue((new File(args[1])).exists());
		assertTrue((new File(args[2])).exists());
		XMLImporter.main(args);
		DatabaseSingleton.initialize(args[1]);
		OntologyDatabase db = DatabaseSingleton.getInstance().getOntologyDatabase();
		Collection<OntologyHandle> data = db.getOntologies();
		OntologyHandle test = null;
		for (OntologyHandle handle : data) {
			if (handle.getName().equals("smallontotest")) {
				test = handle;
				break;
			}
		}
		assertNotNull(test);
		Node[] node = {db.getNode(new NodeHandle(test, 1)),
			db.getNode(new NodeHandle(test, 2)),
			db.getNode(new NodeHandle(test, 3))};
		assertTrue(node[0].getPrimaryName().equals("test2"));
		Collection<NodeName> nodeNames = node[0].getNames();
		for (NodeName name : nodeNames) {
			boolean correctName = name.getName().equals("test");
			correctName = correctName || name.getName().equals("test2");
			assertTrue(correctName);
			assertEquals("testName", name.getType());
		}
		assertTrue(node[0].getAssociatedNodes(AssociationType.DEFAULT.getValue()).contains(node[1]));
		assertTrue(node[2].getAssociatedNodes(AssociationType.CONTAINS_A.getValue()).contains(node[1]));
		assertEquals(ComparisonMode.CLEAN, node[1].getPrimaryNameDescr().getComparisonMode());
	}
}
