/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.ontology.importer.ncbi;

import de.unibi.techfak.scie.ontology.importer.ncbi.NCBIImporter;
import de.unibi.techfak.scie.ontology.driver.NodeName;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import junit.framework.TestCase;
import org.apache.commons.lang.ArrayUtils;

/**
 *
 * @author Andreas Stoeckel -- astoecke(at)techfak.uni-bielefeld.de
 */
public class NCBIImporterTest extends TestCase {
	
	public NCBIImporterTest(String testName) {
		super(testName);
	}

	/**
	 * Test of cleanNodeNames method, of class NCBIImporter.
	 */
	public void testCleanNodeNames() {
		List<NodeName> names = new ArrayList();
		names.add(new NodeName("russian  desman sp. OISKI POISKI ", "1"));
		names.add(new NodeName("russian  desman (OISKI POISKI)", "2"));
		names.add(new NodeName("russian  desman \"OISKI POISKI\"", "3"));
		names.add(new NodeName("russian  desman 'OISKI POISKI'", "4"));
		names.add(new NodeName("russian  desman ebu, 1934", "4"));
		names.add(new NodeName("russian desman bbc & ebu, 1934 ", "4"));
		names.add(new NodeName("russian desman in bbc & ebu, 1934 ", "4"));
		names.add(new NodeName("   polar bear "));
		names.add(new NodeName(" schroedinger's cat's box 'fancy name'  "));

		Collection<NodeName> cleanedNames = NCBIImporter.cleanNodeNames(names);

		String expected[] = {"russian desman", "polar bear", "schroedinger's cat's box"};

		assertEquals("Cleaned Names Count", 3, cleanedNames.size());
		for (NodeName cleanedName: cleanedNames) {
			int idx = ArrayUtils.indexOf(expected, cleanedName.getName());
			assertTrue("Cleaned Name", idx >= 0);
			assertTrue("Cleaned Name", expected[idx] != null);
			expected[idx] = null;
		}
	}
	
}
